==> office-ui-fabric-vue-7.0.26.tgz: package/lib/components/SpinButton/SpinButton.js <==
import '../node_modules/core-js/modules/es.date.to-string.js';
import '../node_modules/core-js/modules/es.object.to-string.js';
import '../node_modules/core-js/modules/es.reflect.construct.js';
import '../node_modules/core-js/modules/es.regexp.to-string.js';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Watch, Component } from 'vue-property-decorator';
import { precisionRound, calculatePrecision } from '@uifabric-vue/utilities';
import BaseComponent from '../BaseComponent.js';
import '../node_modules/core-js/modules/es.symbol.js';
import '../node_modules/core-js/modules/es.array.filter.js';
import '../node_modules/core-js/modules/es.array.for-each.js';
import '../node_modules/core-js/modules/es.object.define-properties.js';
import '../node_modules/core-js/modules/es.object.define-property.js';
import '../node_modules/core-js/modules/es.object.get-own-property-descriptor.js';
import '../node_modules/core-js/modules/es.object.get-own-property-descriptors.js';
import '../node_modules/core-js/modules/es.object.keys.js';
import '../node_modules/core-js/modules/web.dom-collections.for-each.js';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import '../node_modules/core-js/modules/es.number.constructor.js';
import { Icon } from '../Icon/index.js';
import '../node_modules/core-js/modules/web.timers.js';
import { Position } from '../../utilities/positioning/positioning.types.js';
import '../../utilities/positioning/positioning.js';
import { IconButton } from '../Button/IconButton/IconButton.js';
import { Label } from '../Label/index.js';
import { getClassNames } from './SpinButton.classNames.js';
import { getArrowButtonStyles, getStyles } from './SpinButton.styles.js';

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }
var KeyboardSpinDirection;

(function (KeyboardSpinDirection) {
  KeyboardSpinDirection[KeyboardSpinDirection["down"] = -1] = "down";
  KeyboardSpinDirection[KeyboardSpinDirection["notSpinning"] = 0] = "notSpinning";
  KeyboardSpinDirection[KeyboardSpinDirection["up"] = 1] = "up";
})(KeyboardSpinDirection || (KeyboardSpinDirection = {}));

var SpinButton = function (_BaseComponent) {
  _inherits(SpinButton, _BaseComponent);

  var _super = _createSuper(SpinButton);

  function SpinButton() {
    var _this;

    _classCallCheck(this, SpinButton);

    _this = _super.apply(this, arguments);
    _this.Position = Position;
    _this.getArrowButtonStyles = getArrowButtonStyles;
    _this.customUpArrowButtonStyles = {};
    _this.customDownArrowButtonStyles = {};
    _this.internalValue = _this.value || _this.defaultValue;
    _this.INITIAL_STEP_DELAY = 400;
    _this.STEP_DELAY = 75;
    _this.isFocused = false;
    _this.keyboardSpinDirection = KeyboardSpinDirection.notSpinning;
    return _this;
  }

  _createClass(SpinButton, [{
    key: "onValueChanged",
    value: function onValueChanged(value) {
      this.$emit('input', value);
    }
  }, {
    key: "updateValue",
    value: function updateValue(value) {
      var newValue = precisionRound(value, this.precision);
      this.internalValue = newValue;
      return newValue;
    }
  }, {
    key: "onIncrement",
    value: function onIncrement() {
      var newValue = Math.min(this.internalValue + this.step, this.max);
      return this.updateValue(newValue);
    }
  }, {
    key: "onDecrement",
    value: function onDecrement() {
      var newValue = Math.max(this.internalValue - this.step, this.min);
      return this.updateValue(newValue);
    }
  }, {
    key: "startSpin",
    value: function startSpin(dir) {
      var _this2 = this;

      var newValue = dir === 1 ? this.onIncrement() : this.onDecrement();
      newValue = precisionRound(newValue, this.precision);
      this.internalValue = newValue;
      this.timeout = setTimeout(function () {
        _this2.interval = setInterval(function () {
          var newValue = dir === 1 ? _this2.onIncrement() : _this2.onDecrement();
          newValue = precisionRound(newValue, _this2.precision);
          _this2.internalValue = newValue;
        }, _this2.STEP_DELAY);
      }, this.INITIAL_STEP_DELAY);
    }
  }, {
    key: "stopSpin",
    value: function stopSpin() {
      clearTimeout(this.timeout);
      clearInterval(this.interval);
    }
  }, {
    key: "render",
    value: function render() {
      var _this3 = this;

      var h = arguments[0];
      var theme = this.theme,
          customUpArrowButtonStyles = this.customUpArrowButtonStyles,
          customDownArrowButtonStyles = this.customDownArrowButtonStyles,
          classNames = this.classNames,
          labelPosition = this.labelPosition,
          iconProps = this.iconProps,
          label = this.label,
          internalValue = this.internalValue;
      return h("div", {
        "class": classNames.root
      }, [labelPosition !== Position.bottom && (iconProps || label) && h("div", {
        "class": classNames.labelWrapper
      }, [iconProps && h(Icon, {
        "attrs": {
          "class-name": classNames.icon
        },
        "props": _objectSpread({}, iconProps)
      }), h(Label, {
        "attrs": {
          "for": "SpinButton".concat(this.uid)
        },
        "class": classNames.label
      }, [label])]), h("div", {
        "class": classNames.spinButtonWrapper
      }, [h("input", {
        "attrs": {
          "id": "SpinButton".concat(this.uid),
          "type": "text",
          "role": "spinbutton"
        },
        "class": classNames.input,
        "domProps": {
          "value": internalValue
        },
        "on": {
          "focus": function focus() {
            return _this3.isFocused = true;
          },
          "blur": function blur() {
            return _this3.isFocused = false;
          },
          "input": function input(ev) {
            return _this3.internalValue = +(ev.target.value || 0);
          }
        }
      }), h("span", {
        "class": classNames.arrowBox
      }, [h(IconButton, {
        "class": "ms-UpButton",
        "attrs": {
          "styles": getArrowButtonStyles(theme, true, customUpArrowButtonStyles),
          "icon-props": {
            iconName: 'ChevronUpSmall'
          }
        },
        "nativeOn": {
          "mousedown": function mousedown() {
            return _this3.startSpin(1);
          },
          "mouseup": function mouseup() {
            return _this3.stopSpin();
          }
        }
      }), h(IconButton, {
        "class": "ms-DownButton",
        "attrs": {
          "styles": getArrowButtonStyles(theme, false, customDownArrowButtonStyles),
          "icon-props": {
            iconName: 'ChevronDownSmall'
          }
        },
        "nativeOn": {
          "mousedown": function mousedown() {
            return _this3.startSpin(-1);
          },
          "mouseup": function mouseup() {
            return _this3.stopSpin();
          }
        }
      })])]), labelPosition === Position.bottom && (iconProps || label) && h("div", {
        "class": classNames.labelWrapper
      }, [iconProps && h(Icon, {
        "attrs": {
          "class-name": classNames.icon
        },
        "props": _objectSpread({}, iconProps)
      }), label && h(Label, {
        "attrs": {
          "for": "SpinButton".concat(this.uid)
        },
        "class": classNames.label
      }, [label])])]);
    }
  }, {
    key: "classNames",
    get: function get() {
      var theme = this.theme,
          styles = this.styles,
          className = this.className,
          disabled = this.disabled,
          isFocused = this.isFocused,
          keyboardSpinDirection = this.keyboardSpinDirection,
          labelPosition = this.labelPosition;
      return getClassNames(getStyles(theme, styles), disabled, isFocused, keyboardSpinDirection, labelPosition, className);
    }
  }, {
    key: "precision",
    get: function get() {
      var precision = Math.max(calculatePrecision(this.step), 0);
      return precision;
    }
  }]);

  return SpinButton;
}(BaseComponent);

__decorate([Prop({
  "default": false
}), __metadata("design:type", Boolean)], SpinButton.prototype, "disabled", void 0);

__decorate([Prop({
  "default": false
}), __metadata("design:type", Boolean)], SpinButton.prototype, "required", void 0);

__decorate([Prop({
  "default": 0
}), __metadata("design:type", Number)], SpinButton.prototype, "defaultValue", void 0);

__decorate([Prop({
  "default": null
}), __metadata("design:type", Number)], SpinButton.prototype, "value", void 0);

__decorate([Prop({
  "default": null
}), __metadata("design:type", String)], SpinButton.prototype, "label", void 0);

__decorate([Prop({
  "default": Position.start
}), __metadata("design:type", Number)], SpinButton.prototype, "labelPosition", void 0);

__decorate([Prop({
  "default": 0
}), __metadata("design:type", Number)], SpinButton.prototype, "min", void 0);

__decorate([Prop({
  "default": 10
}), __metadata("design:type", Number)], SpinButton.prototype, "max", void 0);

__decorate([Prop({
  "default": 1
}), __metadata("design:type", Number)], SpinButton.prototype, "step", void 0);

__decorate([Prop({
  type: Object,
  "default": function _default() {}
}), __metadata("design:type", Object)], SpinButton.prototype, "iconProps", void 0);

__decorate([Watch('internalValue'), __metadata("design:type", Function), __metadata("design:paramtypes", [String]), __metadata("design:returntype", void 0)], SpinButton.prototype, "onValueChanged", null);

SpinButton = __decorate([Component({
  components: {
    IconButton: IconButton,
    Icon: Icon,
    Label: Label
  }
})], SpinButton);

export { KeyboardSpinDirection, SpinButton };

==> office-ui-fabric-vue-7.0.27.tgz: package/lib/components/SpinButton/SpinButton.js <==
import 'core-js/modules/es.object.to-string';
import 'core-js/modules/es.reflect.construct';
import 'core-js/modules/es.regexp.to-string';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Watch, Component } from 'vue-property-decorator';
import { precisionRound, calculatePrecision } from '@uifabric-vue/utilities';
import BaseComponent from '../BaseComponent.js';
import 'core-js/modules/es.symbol';
import 'core-js/modules/es.array.filter';
import 'core-js/modules/es.array.for-each';
import 'core-js/modules/es.object.get-own-property-descriptor';
import 'core-js/modules/es.object.get-own-property-descriptors';
import 'core-js/modules/es.object.keys';
import 'core-js/modules/web.dom-collections.for-each';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import 'core-js/modules/es.number.constructor';
import { Icon } from '../Icon/index.js';
import { Position } from '../../utilities/positioning/positioning.types.js';
import '../../utilities/positioning/positioning.js';
import { IconButton } from '../Button/IconButton/IconButton.js';
import { Label } from '../Label/index.js';
import { getClassNames } from './SpinButton.classNames.js';
import { getArrowButtonStyles, getStyles } from './SpinButton.styles.js';

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }
var KeyboardSpinDirection;

(function (KeyboardSpinDirection) {
  KeyboardSpinDirection[KeyboardSpinDirection["down"] = -1] = "down";
  KeyboardSpinDirection[KeyboardSpinDirection["notSpinning"] = 0] = "notSpinning";
  KeyboardSpinDirection[KeyboardSpinDirection["up"] = 1] = "up";
})(KeyboardSpinDirection || (KeyboardSpinDirection = {}));

var SpinButton = function (_BaseComponent) {
  _inherits(SpinButton, _BaseComponent);

  var _super = _createSuper(SpinButton);

  function SpinButton() {
    var _this;

    _classCallCheck(this, SpinButton);

    _this = _super.apply(this, arguments);
    _this.Position = Position;
    _this.getArrowButtonStyles = getArrowButtonStyles;
    _this.customUpArrowButtonStyles = {};
    _this.customDownArrowButtonStyles = {};
    _this.internalValue = _this.value || _this.defaultValue;
    _this.INITIAL_STEP_DELAY = 400;
    _this.STEP_DELAY = 75;
    _this.isFocused = false;
    _this.keyboardSpinDirection = KeyboardSpinDirection.notSpinning;
    return _this;
  }

  _createClass(SpinButton, [{
    key: "onValueChanged",
    value: function onValueChanged(value) {
      this.$emit('input', value);
    }
  }, {
    key: "updateValue",
    value: function updateValue(value) {
      var newValue = precisionRound(value, this.precision);
      this.internalValue = newValue;
      return newValue;
    }
  }, {
    key: "onIncrement",
    value: function onIncrement() {
      var newValue = Math.min(this.internalValue + this.step, this.max);
      return this.updateValue(newValue);
    }
  }, {
    key: "onDecrement",
    value: function onDecrement() {
      var newValue = Math.max(this.internalValue - this.step, this.min);
      return this.updateValue(newValue);
    }
  }, {
    key: "startSpin",
    value: function startSpin(dir) {
      var _this2 = this;

      var newValue = dir === 1 ? this.onIncrement() : this.onDecrement();
      newValue = precisionRound(newValue, this.precision);
      this.internalValue = newValue;
      this.timeout = setTimeout(function () {
        _this2.interval = setInterval(function () {
          var newValue = dir === 1 ? _this2.onIncrement() : _this2.onDecrement();
          newValue = precisionRound(newValue, _this2.precision);
          _this2.internalValue = newValue;
        }, _this2.STEP_DELAY);
      }, this.INITIAL_STEP_DELAY);
    }
  }, {
    key: "stopSpin",
    value: function stopSpin() {
      clearTimeout(this.timeout);
      clearInterval(this.interval);
    }
  }, {
    key: "render",
    value: function render() {
      var _this3 = this;

      var h = arguments[0];
      var theme = this.theme,
          customUpArrowButtonStyles = this.customUpArrowButtonStyles,
          customDownArrowButtonStyles = this.customDownArrowButtonStyles,
          classNames = this.classNames,
          labelPosition = this.labelPosition,
          iconProps = this.iconProps,
          label = this.label,
          internalValue = this.internalValue;
      return h("div", {
        "class": classNames.root
      }, [labelPosition !== Position.bottom && (iconProps || label) && h("div", {
        "class": classNames.labelWrapper
      }, [iconProps && h(Icon, {
        "attrs": {
          "class-name": classNames.icon
        },
        "props": _objectSpread({}, iconProps)
      }), h(Label, {
        "attrs": {
          "for": "SpinButton".concat(this.uid)
        },
        "class": classNames.label
      }, [label])]), h("div", {
        "class": classNames.spinButtonWrapper
      }, [h("input", {
        "attrs": {
          "id": "SpinButton".concat(this.uid),
          "type": "text",
          "role": "spinbutton"
        },
        "class": classNames.input,
        "domProps": {
          "value": internalValue
        },
        "on": {
          "focus": function focus() {
            return _this3.isFocused = true;
          },
          "blur": function blur() {
            return _this3.isFocused = false;
          },
          "input": function input(ev) {
            return _this3.internalValue = +(ev.target.value || 0);
          }
        }
      }), h("span", {
        "class": classNames.arrowBox
      }, [h(IconButton, {
        "class": "ms-UpButton",
        "attrs": {
          "styles": getArrowButtonStyles(theme, true, customUpArrowButtonStyles),
          "icon-props": {
            iconName: 'ChevronUpSmall'
          }
        },
        "nativeOn": {
          "mousedown": function mousedown() {
            return _this3.startSpin(1);
          },
          "mouseup": function mouseup() {
            return _this3.stopSpin();
          }
        }
      }), h(IconButton, {
        "class": "ms-DownButton",
        "attrs": {
          "styles": getArrowButtonStyles(theme, false, customDownArrowButtonStyles),
          "icon-props": {
            iconName: 'ChevronDownSmall'
          }
        },
        "nativeOn": {
          "mousedown": function mousedown() {
            return _this3.startSpin(-1);
          },
          "mouseup": function mouseup() {
            return _this3.stopSpin();
          }
        }
      })])]), labelPosition === Position.bottom && (iconProps || label) && h("div", {
        "class": classNames.labelWrapper
      }, [iconProps && h(Icon, {
        "attrs": {
          "class-name": classNames.icon
        },
        "props": _objectSpread({}, iconProps)
      }), label && h(Label, {
        "attrs": {
          "for": "SpinButton".concat(this.uid)
        },
        "class": classNames.label
      }, [label])])]);
    }
  }, {
    key: "classNames",
    get: function get() {
      var theme = this.theme,
          styles = this.styles,
          className = this.className,
          disabled = this.disabled,
          isFocused = this.isFocused,
          keyboardSpinDirection = this.keyboardSpinDirection,
          labelPosition = this.labelPosition;
      return getClassNames(getStyles(theme, styles), disabled, isFocused, keyboardSpinDirection, labelPosition, className);
    }
  }, {
    key: "precision",
    get: function get() {
      var precision = Math.max(calculatePrecision(this.step), 0);
      return precision;
    }
  }]);

  return SpinButton;
}(BaseComponent);

__decorate([Prop({
  default: false
}), __metadata("design:type", Boolean)], SpinButton.prototype, "disabled", void 0);

__decorate([Prop({
  default: false
}), __metadata("design:type", Boolean)], SpinButton.prototype, "required", void 0);

__decorate([Prop({
  default: 0
}), __metadata("design:type", Number)], SpinButton.prototype, "defaultValue", void 0);

__decorate([Prop({
  default: null
}), __metadata("design:type", Number)], SpinButton.prototype, "value", void 0);

__decorate([Prop({
  default: null
}), __metadata("design:type", String)], SpinButton.prototype, "label", void 0);

__decorate([Prop({
  default: Position.start
}), __metadata("design:type", Number)], SpinButton.prototype, "labelPosition", void 0);

__decorate([Prop({
  default: 0
}), __metadata("design:type", Number)], SpinButton.prototype, "min", void 0);

__decorate([Prop({
  default: 10
}), __metadata("design:type", Number)], SpinButton.prototype, "max", void 0);

__decorate([Prop({
  default: 1
}), __metadata("design:type", Number)], SpinButton.prototype, "step", void 0);

__decorate([Prop({
  type: Object,
  default: function _default() {}
}), __metadata("design:type", Object)], SpinButton.prototype, "iconProps", void 0);

__decorate([Watch('internalValue'), __metadata("design:type", Function), __metadata("design:paramtypes", [String]), __metadata("design:returntype", void 0)], SpinButton.prototype, "onValueChanged", null);

SpinButton = __decorate([Component({
  components: {
    IconButton: IconButton,
    Icon: Icon,
    Label: Label
  }
})], SpinButton);

export { KeyboardSpinDirection, SpinButton };
